# GOSTrocks

This repository includes support functions for a number of geospatial tools used by the Geospatial Operations Support Team (GOST) in the World Bank Data Group. The Notebooks folder contains examples using the various functions.

## Installation

```{shell}
pip install GOSTRocks
```

Future releases can be built from source, but pip will contain the most recent stable version (to be updated).

## Contributing

Please refer to the World Bank's Github [Contributing](docs/CONTRIBUTING.md) guidelines.

## Code of Conduct

The <span style="color:#3EACAD">template</span> maintains a [Code of Conduct](docs/CODE_OF_CONDUCT.md) to ensure an inclusive and respectful environment for everyone. Please adhere to it in all interactions within our community.

## License

This project is licensed under the [**Mozilla Public License**](https://www.mozilla.org/en-US/MPL).
